You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@accumulo.apache.org by GitBox <gi...@apache.org> on 2018/08/28 19:44:42 UTC

[GitHub] milleruntime closed pull request #620: Spelling corrections in comments/javadocs

milleruntime closed pull request #620: Spelling corrections in comments/javadocs
URL: https://github.com/apache/accumulo/pull/620
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/assemble/build.sh b/assemble/build.sh
index a5251a39b2..85e49f40ed 100755
--- a/assemble/build.sh
+++ b/assemble/build.sh
@@ -73,7 +73,7 @@ gitCommit()  { gitCommits -n1 "$@"; }
 gitSubject() { pretty %s "$@"; }
 
 createEmail() {
-  # $1 version (optional); $2 rc seqence num (optional); $3 staging repo num (optional)
+  # $1 version (optional); $2 rc sequence num (optional); $3 staging repo num (optional)
   local ver; [[ -n "$1" ]] && ver=$1 || ver=$(prompter 'version to be released (eg. x.y.z)' '[0-9]+[.][0-9]+[.][0-9]+')
   local rc; [[ -n "$2" ]] && rc=$2 || rc=$(prompter 'release candidate sequence number (eg. 1, 2, etc.)' '[0-9]+')
   local stagingrepo; [[ -n "$3" ]] && stagingrepo=$3 || stagingrepo=$(prompter 'staging repository number from https://repository.apache.org/#stagingRepositories' '[0-9]+')
diff --git a/assemble/conf/templates/hadoop-metrics2-accumulo.properties b/assemble/conf/templates/hadoop-metrics2-accumulo.properties
index f3593b5ea4..56670e900f 100644
--- a/assemble/conf/templates/hadoop-metrics2-accumulo.properties
+++ b/assemble/conf/templates/hadoop-metrics2-accumulo.properties
@@ -74,7 +74,7 @@
 # accumulo.sink.ganglia.dmax=jvm.metrics.threadsBlocked=70,jvm.metrics.memHeapUsedM=40
 
 # Tag values to use for the ganglia prefix. If not defined no tags are used.
-# If '*' all tags are used. If specifiying multiple tags separate them with
+# If '*' all tags are used. If specifying multiple tags separate them with
 # commas. Note that the last segment of the property name is the context name.
 #
 # accumulo.sink.ganglia.tagsForPrefix.jvm=ProcesName
diff --git a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapred/AccumuloFileOutputFormat.java b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapred/AccumuloFileOutputFormat.java
index a88d1f4c93..553ccbd632 100644
--- a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapred/AccumuloFileOutputFormat.java
+++ b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapred/AccumuloFileOutputFormat.java
@@ -154,12 +154,12 @@ public static void setSampler(JobConf job, SamplerConfiguration samplerConfig) {
    *
    * @param job
    *          The Hadoop job instance to be configured
-   * @param sumarizerConfigs
+   * @param summarizerConfigs
    *          summarizer configurations
    * @since 2.0.0
    */
-  public static void setSummarizers(JobConf job, SummarizerConfiguration... sumarizerConfigs) {
-    FileOutputConfigurator.setSummarizers(CLASS, job, sumarizerConfigs);
+  public static void setSummarizers(JobConf job, SummarizerConfiguration... summarizerConfigs) {
+    FileOutputConfigurator.setSummarizers(CLASS, job, summarizerConfigs);
   }
 
   @Override
diff --git a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/AccumuloFileOutputFormat.java b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/AccumuloFileOutputFormat.java
index d37612a865..9cd37943ba 100644
--- a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/AccumuloFileOutputFormat.java
+++ b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/AccumuloFileOutputFormat.java
@@ -152,12 +152,12 @@ public static void setSampler(Job job, SamplerConfiguration samplerConfig) {
    *
    * @param job
    *          The Hadoop job instance to be configured
-   * @param sumarizerConfigs
+   * @param summarizerConfigs
    *          summarizer configurations
    * @since 2.0.0
    */
-  public static void setSummarizers(Job job, SummarizerConfiguration... sumarizerConfigs) {
-    FileOutputConfigurator.setSummarizers(CLASS, job.getConfiguration(), sumarizerConfigs);
+  public static void setSummarizers(Job job, SummarizerConfiguration... summarizerConfigs) {
+    FileOutputConfigurator.setSummarizers(CLASS, job.getConfiguration(), summarizerConfigs);
   }
 
   @Override
diff --git a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/lib/impl/ConfiguratorBase.java b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/lib/impl/ConfiguratorBase.java
index 165f53e322..17b52b02af 100644
--- a/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/lib/impl/ConfiguratorBase.java
+++ b/client/mapreduce/src/main/java/org/apache/accumulo/core/client/mapreduce/lib/impl/ConfiguratorBase.java
@@ -342,7 +342,7 @@ public static void setZooKeeperInstance(Class<?> implementingClass, Configuratio
    * Creates an Accumulo {@link Connector} based on the configuration
    *
    * @param implementingClass
-   *          class whose name will be used as a prefix for the property configu
+   *          class whose name will be used as a prefix for the property configuration
    * @param conf
    *          Hadoop configuration object
    * @return Accumulo connector
diff --git a/core/src/main/java/org/apache/accumulo/core/bloomfilter/Filter.java b/core/src/main/java/org/apache/accumulo/core/bloomfilter/Filter.java
index 8d30a052f7..ddee51ddef 100644
--- a/core/src/main/java/org/apache/accumulo/core/bloomfilter/Filter.java
+++ b/core/src/main/java/org/apache/accumulo/core/bloomfilter/Filter.java
@@ -126,7 +126,7 @@ protected Filter(final int vectorSize, final int nbHash, final int hashType) {
   public abstract boolean membershipTest(Key key);
 
   /**
-   * Peforms a logical AND between <i>this</i> filter and a specified filter.
+   * Performs a logical AND between <i>this</i> filter and a specified filter.
    * <p>
    * <b>Invariant</b>: The result is assigned to <i>this</i> filter.
    *
@@ -136,7 +136,7 @@ protected Filter(final int vectorSize, final int nbHash, final int hashType) {
   public abstract void and(Filter filter);
 
   /**
-   * Peforms a logical OR between <i>this</i> filter and a specified filter.
+   * Performs a logical OR between <i>this</i> filter and a specified filter.
    * <p>
    * <b>Invariant</b>: The result is assigned to <i>this</i> filter.
    *
@@ -146,7 +146,7 @@ protected Filter(final int vectorSize, final int nbHash, final int hashType) {
   public abstract void or(Filter filter);
 
   /**
-   * Peforms a logical XOR between <i>this</i> filter and a specified filter.
+   * Performs a logical XOR between <i>this</i> filter and a specified filter.
    * <p>
    * <b>Invariant</b>: The result is assigned to <i>this</i> filter.
    *
@@ -188,7 +188,7 @@ public void readFields(final DataInput in) throws IOException {
       this.nbHash = ver;
       this.hashType = Hash.JENKINS_HASH;
 
-    } else if (ver == VERSION | ver == VERSION + 1) { // Support for directly serialzing the bitset
+    } else if (ver == VERSION | ver == VERSION + 1) { // Support for directly serializing the bitset
       this.nbHash = in.readInt();
       this.hashType = in.readByte();
     } else {
diff --git a/core/src/main/java/org/apache/accumulo/core/client/Connector.java b/core/src/main/java/org/apache/accumulo/core/client/Connector.java
index 78b9e8d2db..b4770d116e 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/Connector.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/Connector.java
@@ -527,7 +527,7 @@ public abstract Connector changeUser(String principal, AuthenticationToken token
      * @param path
      *          Path to keystore
      * @param password
-     *          Password used to encyrpt key store
+     *          Password used to encrypt key store
      * @param type
      *          Key store type
      * @return this builder
diff --git a/core/src/main/java/org/apache/accumulo/core/client/ScannerBase.java b/core/src/main/java/org/apache/accumulo/core/client/ScannerBase.java
index 207b4affad..c32618b015 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/ScannerBase.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/ScannerBase.java
@@ -210,7 +210,7 @@
    *     connector.tableOperations().getSamplerConfiguration(table);
    *   // verify table's sample data is generated in an expected way before using
    *   userCode.verifySamplerConfig(samplerConfig);
-   *   scanner.setSamplerCongiguration(samplerConfig);
+   *   scanner.setSamplerConfiguration(samplerConfig);
    * </code>
    * </pre>
    *
diff --git a/core/src/main/java/org/apache/accumulo/core/client/admin/ActiveCompaction.java b/core/src/main/java/org/apache/accumulo/core/client/admin/ActiveCompaction.java
index 16d086ddb3..15ec6fb295 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/admin/ActiveCompaction.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/admin/ActiveCompaction.java
@@ -77,7 +77,7 @@
   public abstract String getTable() throws TableNotFoundException;
 
   /**
-   * @return tablet thats is compacting
+   * @return tablet that is compacting
    * @since 1.7.0
    */
   public abstract TabletId getTablet();
diff --git a/core/src/main/java/org/apache/accumulo/core/client/admin/TableOperations.java b/core/src/main/java/org/apache/accumulo/core/client/admin/TableOperations.java
index 894b2fc60c..0970c17276 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/admin/TableOperations.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/admin/TableOperations.java
@@ -365,7 +365,7 @@ void compact(String tableName, Text start, Text end, List<IteratorSetting> itera
    *
    * <p>
    * Only one compact call at a time can pass iterators and/or a compaction strategy. If two threads
-   * call compaction with iterators and/or a copmaction strategy, then one will fail.
+   * call compaction with iterators and/or a compaction strategy, then one will fail.
    *
    * @param tableName
    *          the table to compact
diff --git a/core/src/main/java/org/apache/accumulo/core/client/impl/TableOperationsImpl.java b/core/src/main/java/org/apache/accumulo/core/client/impl/TableOperationsImpl.java
index 2ca0ad6f98..80cfc7a4e9 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/impl/TableOperationsImpl.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/impl/TableOperationsImpl.java
@@ -1172,7 +1172,7 @@ public void importDirectory(String tableName, String dir, String failureDir, boo
     checkArgument(tableName != null, "tableName is null");
     checkArgument(dir != null, "dir is null");
     checkArgument(failureDir != null, "failureDir is null");
-    // check for table existance
+    // check for table existence
     Tables.getTableId(context, tableName);
 
     Path dirPath = checkPath(dir, "Bulk", "");
diff --git a/core/src/main/java/org/apache/accumulo/core/client/impl/TabletServerBatchWriter.java b/core/src/main/java/org/apache/accumulo/core/client/impl/TabletServerBatchWriter.java
index 425d8f00fd..512b33d63c 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/impl/TabletServerBatchWriter.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/impl/TabletServerBatchWriter.java
@@ -718,7 +718,7 @@ else if (Tables.getTableState(context, tableId) == TableState.OFFLINE)
         updateUnknownErrors(e.getMessage(), e);
       }
 
-      // an error ocurred
+      // an error occurred
       binnedMutations.clear();
 
     }
diff --git a/core/src/main/java/org/apache/accumulo/core/client/impl/ThriftScanner.java b/core/src/main/java/org/apache/accumulo/core/client/impl/ThriftScanner.java
index 4d33447da2..5c54bd39a2 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/impl/ThriftScanner.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/impl/ThriftScanner.java
@@ -97,7 +97,7 @@ public static boolean getBatchFromServer(ClientContext context, Range range, Key
       TInfo tinfo = Tracer.traceInfo();
       TabletClientService.Client client = ThriftUtil.getTServerClient(parsedServer, context);
       try {
-        // not reading whole rows (or stopping on row boundries) so there is no need to enable
+        // not reading whole rows (or stopping on row boundaries) so there is no need to enable
         // isolation below
         ScanState scanState = new ScanState(context, extent.getTableId(), authorizations, range,
             fetchedColumns, size, serverSideIteratorList, serverSideIteratorOptions, false,
@@ -210,7 +210,7 @@ public ScanState(ClientContext context, Table.ID tableId, Authorizations authori
       this.batchTimeOut = batchTimeOut;
 
       if (executionHints == null || executionHints.size() == 0)
-        this.executionHints = null; // avoid thrift serlialization for empty map
+        this.executionHints = null; // avoid thrift serialization for empty map
       else
         this.executionHints = executionHints;
     }
diff --git a/core/src/main/java/org/apache/accumulo/core/client/sample/Sampler.java b/core/src/main/java/org/apache/accumulo/core/client/sample/Sampler.java
index a52c9cfbd6..2c9a8c1a52 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/sample/Sampler.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/sample/Sampler.java
@@ -20,7 +20,7 @@
 import org.apache.accumulo.core.data.Key;
 
 /**
- * A function that decides which key values are stored in a tables sample. As Accumuo compacts data
+ * A function that decides which key values are stored in a tables sample. As Accumulo compacts data
  * and creates rfiles it uses a Sampler to decided what to store in the rfiles sample section. The
  * class name of the Sampler and the Samplers configuration are stored in each rfile. A scan of a
  * tables sample will only succeed if all rfiles were created with the same sampler and sampler
@@ -56,7 +56,7 @@
   /**
    * @param k
    *          A key that was written to a rfile.
-   * @return True if the key (and its associtated value) should be stored in the rfile's sample.
+   * @return True if the key (and its associated value) should be stored in the rfile's sample.
    *         Return false if it should not be included.
    */
   boolean accept(Key k);
diff --git a/core/src/main/java/org/apache/accumulo/core/client/sample/SamplerConfiguration.java b/core/src/main/java/org/apache/accumulo/core/client/sample/SamplerConfiguration.java
index 607daa2061..b5aee0b6c1 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/sample/SamplerConfiguration.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/sample/SamplerConfiguration.java
@@ -26,7 +26,7 @@
 import java.util.Map.Entry;
 
 /**
- * This class encapsultes configuration and options needed to setup and use sampling.
+ * This class encapsulates configuration and options needed to setup and use sampling.
  *
  * @since 1.8.0
  */
diff --git a/core/src/main/java/org/apache/accumulo/core/client/summary/CountingSummarizer.java b/core/src/main/java/org/apache/accumulo/core/client/summary/CountingSummarizer.java
index fda7cd38b5..5e69cf13a0 100644
--- a/core/src/main/java/org/apache/accumulo/core/client/summary/CountingSummarizer.java
+++ b/core/src/main/java/org/apache/accumulo/core/client/summary/CountingSummarizer.java
@@ -122,7 +122,7 @@
 
   /**
    * This is the name of the statistic that tracks how many counter objects were ignored because
-   * they were too long. The maximum lenght is specified by {@link #MAX_COUNTER_LEN_OPT}.
+   * they were too long. The maximum length is specified by {@link #MAX_COUNTER_LEN_OPT}.
    */
   public static final String TOO_LONG_STAT = "tooLong";
 
diff --git a/core/src/main/java/org/apache/accumulo/core/conf/Interpolated.java b/core/src/main/java/org/apache/accumulo/core/conf/Interpolated.java
index 6a7b0b4f3b..b61de40791 100644
--- a/core/src/main/java/org/apache/accumulo/core/conf/Interpolated.java
+++ b/core/src/main/java/org/apache/accumulo/core/conf/Interpolated.java
@@ -25,7 +25,7 @@
  * be interpolated with system properties.
  *
  * Interpolated items need to be careful, as JVM properties could be updates and we may want that
- * propogated when those changes occur. Currently only VFS_CLASSLOADER_CACHE_DIR, which isn't ZK
+ * propagated when those changes occur. Currently only VFS_CLASSLOADER_CACHE_DIR, which isn't ZK
  * mutable, is interpolated, so this shouldn't be an issue as java.io.tmpdir also shouldn't be
  * changing.
  */
diff --git a/core/src/main/java/org/apache/accumulo/core/data/Key.java b/core/src/main/java/org/apache/accumulo/core/data/Key.java
index ea9d1eafa3..d1caf3e018 100644
--- a/core/src/main/java/org/apache/accumulo/core/data/Key.java
+++ b/core/src/main/java/org/apache/accumulo/core/data/Key.java
@@ -783,7 +783,7 @@ public final Text getColumnVisibility() {
   }
 
   /**
-   * Writes the column visibvility into the given <code>Text</code>. This method gives users control
+   * Writes the column visibility into the given <code>Text</code>. This method gives users control
    * over allocation of Text objects by copying into the passed in text.
    *
    * @param cv
@@ -912,7 +912,7 @@ public boolean equals(Key other, PartialKey part) {
    * Compares elements of a key given by a {@link PartialKey}. The corresponding elements (row,
    * column family, column qualifier, column visibility, timestamp, and delete marker) are compared
    * in order until unequal elements are found. The row, column family, column qualifier, and column
-   * visibility are compared lexographically and sorted ascending. The timestamps are compared
+   * visibility are compared lexicographically and sorted ascending. The timestamps are compared
    * numerically and sorted descending so that the most recent data comes first. Lastly, a delete
    * marker of true sorts before a delete marker of false. The result of the first unequal
    * comparison is returned.
@@ -1128,7 +1128,7 @@ private static boolean isEqual(byte a1[], byte a2[]) {
 
     // since sorted data is usually compared in accumulo,
     // the prefixes will normally be the same... so compare
-    // the last two charachters first.. the most likely place
+    // the last two characters first.. the most likely place
     // to have disorder is at end of the strings when the
     // data is sorted... if those are the same compare the rest
     // of the data forward... comparing backwards is slower
diff --git a/core/src/main/java/org/apache/accumulo/core/data/Value.java b/core/src/main/java/org/apache/accumulo/core/data/Value.java
index f38c89a7ee..2e81e15c26 100644
--- a/core/src/main/java/org/apache/accumulo/core/data/Value.java
+++ b/core/src/main/java/org/apache/accumulo/core/data/Value.java
@@ -148,7 +148,7 @@ public Value(final Value ibw) {
    * @param newData
    *          source of copy, may not be null
    * @param offset
-   *          the offset in newData to start with for valye bytes
+   *          the offset in newData to start with for value bytes
    * @param length
    *          the number of bytes in the value
    * @throws IndexOutOfBoundsException
diff --git a/core/src/main/java/org/apache/accumulo/core/data/impl/KeyExtent.java b/core/src/main/java/org/apache/accumulo/core/data/impl/KeyExtent.java
index c20ad5246f..f42d265a86 100644
--- a/core/src/main/java/org/apache/accumulo/core/data/impl/KeyExtent.java
+++ b/core/src/main/java/org/apache/accumulo/core/data/impl/KeyExtent.java
@@ -345,7 +345,7 @@ public Mutation getPrevRowUpdateMutation() {
               keys.add(ckes);
             }
           } else {
-            // no null prevend or endrows and no empty string start or end rows
+            // no null prevEnd or endRows and no empty string start or end rows
             if (ckes.getPrevEndRow().compareTo(endRow) < 0
                 && ckes.getEndRow().compareTo(startRow) >= 0) {
               keys.add(ckes);
diff --git a/core/src/main/java/org/apache/accumulo/core/file/blockfile/impl/SeekableByteArrayInputStream.java b/core/src/main/java/org/apache/accumulo/core/file/blockfile/impl/SeekableByteArrayInputStream.java
index 3fd07b4221..e2b00d27bc 100644
--- a/core/src/main/java/org/apache/accumulo/core/file/blockfile/impl/SeekableByteArrayInputStream.java
+++ b/core/src/main/java/org/apache/accumulo/core/file/blockfile/impl/SeekableByteArrayInputStream.java
@@ -29,10 +29,10 @@
 public class SeekableByteArrayInputStream extends InputStream {
 
   // making this volatile for the following case
-  // * thread 1 creates and initalizes byte array
+  // * thread 1 creates and initializes byte array
   // * thread 2 reads from bye array
   // Findbugs complains about this because thread2 may not see any changes to the byte array after
-  // thread 1 set the voltile,
+  // thread 1 set the volatile,
   // however the expectation is that the byte array is static. In the case of it being static,
   // volatile ensures that
   // thread 2 sees all of thread 1 changes before setting the volatile.
diff --git a/core/src/main/java/org/apache/accumulo/core/file/rfile/KeyShortener.java b/core/src/main/java/org/apache/accumulo/core/file/rfile/KeyShortener.java
index 74bd0e3b7c..fee7c6797c 100644
--- a/core/src/main/java/org/apache/accumulo/core/file/rfile/KeyShortener.java
+++ b/core/src/main/java/org/apache/accumulo/core/file/rfile/KeyShortener.java
@@ -29,7 +29,7 @@
 
 /**
  * Code to shorten keys that will be placed into RFile indexes. This code attempts to find a key
- * thats between two keys that shorter.
+ * that's between two keys that shorter.
  */
 public class KeyShortener {
 
diff --git a/core/src/main/java/org/apache/accumulo/core/file/rfile/MultiLevelIndex.java b/core/src/main/java/org/apache/accumulo/core/file/rfile/MultiLevelIndex.java
index a71c79e2cf..576c57732f 100644
--- a/core/src/main/java/org/apache/accumulo/core/file/rfile/MultiLevelIndex.java
+++ b/core/src/main/java/org/apache/accumulo/core/file/rfile/MultiLevelIndex.java
@@ -321,7 +321,7 @@ public void readFields(DataInput in, int version) throws IOException {
 
         CachableBlockFile.CachedBlockRead abr = (CachableBlockFile.CachedBlockRead) in;
         if (abr.isIndexable()) {
-          // this block is cahced, so avoid copy
+          // this block is cached, so avoid copy
           data = abr.getBuffer();
           // use offset data in serialized form and avoid copy
           numOffsets = abr.readInt();
diff --git a/core/src/main/java/org/apache/accumulo/core/file/rfile/RFile.java b/core/src/main/java/org/apache/accumulo/core/file/rfile/RFile.java
index 0c850663f3..044284c7df 100644
--- a/core/src/main/java/org/apache/accumulo/core/file/rfile/RFile.java
+++ b/core/src/main/java/org/apache/accumulo/core/file/rfile/RFile.java
@@ -477,7 +477,7 @@ public void append(Key key, Value value) throws IOException {
         blockWriter = fileWriter.prepareDataBlock();
       } else if (blockWriter.getRawSize() > blockSize) {
 
-        // Look for a key thats short to put in the index, defining short as average or below.
+        // Look for a key that's short to put in the index, defining short as average or below.
         if (averageKeySize == 0) {
           // use the same average for the search for a below average key for a block
           averageKeySize = keyLenStats.getMean();
@@ -978,7 +978,7 @@ private void _seek(Range range) throws IOException {
             && startKey.compareTo(iiter.peekPrevious().getKey()) <= 0) {
           // In the empty space at the end of a block. This can occur when keys are shortened in the
           // index creating index entries that do not exist in the
-          // block. These shortened index entires fall between the last key in a block and first key
+          // block. These shortened index entries fall between the last key in a block and first key
           // in the next block, but may not exist in the data.
           // Just proceed to the next block.
           reseek = false;
diff --git a/core/src/main/java/org/apache/accumulo/core/file/rfile/bcfile/Compression.java b/core/src/main/java/org/apache/accumulo/core/file/rfile/bcfile/Compression.java
index 6d717bba2c..d2a0d7b3d2 100644
--- a/core/src/main/java/org/apache/accumulo/core/file/rfile/bcfile/Compression.java
+++ b/core/src/main/java/org/apache/accumulo/core/file/rfile/bcfile/Compression.java
@@ -127,7 +127,7 @@ public void flush() throws IOException {
 
     LZO(COMPRESSION_LZO) {
       /**
-       * determines if we've checked the codec status. ensures we don't recreate the defualt codec
+       * determines if we've checked the codec status. ensures we don't recreate the default codec
        */
       private final AtomicBoolean checked = new AtomicBoolean(false);
       private static final String defaultClazz = "org.apache.hadoop.io.compress.LzoCodec";
@@ -342,7 +342,7 @@ public boolean isSupported() {
       // Use base type to avoid compile-time dependencies.
       private transient CompressionCodec snappyCodec = null;
       /**
-       * determines if we've checked the codec status. ensures we don't recreate the defualt codec
+       * determines if we've checked the codec status. ensures we don't recreate the default codec
        */
       private final AtomicBoolean checked = new AtomicBoolean(false);
       private static final String defaultClazz = "org.apache.hadoop.io.compress.SnappyCodec";
diff --git a/core/src/main/java/org/apache/accumulo/core/iterators/Combiner.java b/core/src/main/java/org/apache/accumulo/core/iterators/Combiner.java
index f6d31b2956..1e5618b182 100644
--- a/core/src/main/java/org/apache/accumulo/core/iterators/Combiner.java
+++ b/core/src/main/java/org/apache/accumulo/core/iterators/Combiner.java
@@ -300,7 +300,7 @@ public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> op
     }
 
     if (reduceOnFullCompactionOnly && isMajorCompaction && !env.isFullMajorCompaction()) {
-      // adjust configuration so that no columns are combined for a partial maror compaction
+      // adjust configuration so that no columns are combined for a partial major compaction
       combineAllColumns = false;
       combiners = new ColumnSet();
     }
diff --git a/core/src/main/java/org/apache/accumulo/core/iterators/system/ColumnQualifierFilter.java b/core/src/main/java/org/apache/accumulo/core/iterators/system/ColumnQualifierFilter.java
index 75b097e576..5eaa4819e5 100644
--- a/core/src/main/java/org/apache/accumulo/core/iterators/system/ColumnQualifierFilter.java
+++ b/core/src/main/java/org/apache/accumulo/core/iterators/system/ColumnQualifierFilter.java
@@ -69,7 +69,7 @@ public boolean accept(Key key, Value v) {
       return true;
 
     HashSet<ByteSequence> cfset = columnsQualifiers.get(key.getColumnQualifierData());
-    // ensure the columm qualifier goes with a paired column family,
+    // ensure the column qualifier goes with a paired column family,
     // it is possible that a column qualifier could occur with a
     // column family it was not paired with
     return cfset != null && cfset.contains(key.getColumnFamilyData());
diff --git a/core/src/main/java/org/apache/accumulo/core/iterators/user/LargeRowFilter.java b/core/src/main/java/org/apache/accumulo/core/iterators/user/LargeRowFilter.java
index 6bbcf6c446..632547a3cb 100644
--- a/core/src/main/java/org/apache/accumulo/core/iterators/user/LargeRowFilter.java
+++ b/core/src/main/java/org/apache/accumulo/core/iterators/user/LargeRowFilter.java
@@ -52,7 +52,7 @@
 
   private static final ByteSequence EMPTY = new ArrayByteSequence(new byte[] {});
 
-  /* key into hash map, value refers to the row supression limit (maxColumns) */
+  /* key into hash map, value refers to the row suppression limit (maxColumns) */
   private static final String MAX_COLUMNS = "max_columns";
 
   private SortedKeyValueIterator<Key,Value> source;
diff --git a/core/src/main/java/org/apache/accumulo/core/rpc/ThriftUtil.java b/core/src/main/java/org/apache/accumulo/core/rpc/ThriftUtil.java
index 73fb69ba29..e6bd20dc5e 100644
--- a/core/src/main/java/org/apache/accumulo/core/rpc/ThriftUtil.java
+++ b/core/src/main/java/org/apache/accumulo/core/rpc/ThriftUtil.java
@@ -130,7 +130,7 @@ public static TTransportFactory transportFactory() {
 
   /**
    * Create a Thrift client using the given factory with a pooled transport (if available) using the
-   * address, client context and timeou
+   * address, client context and timeout
    *
    * @param factory
    *          Thrift client factory
@@ -443,7 +443,7 @@ static void attemptClientReLogin() {
 
   /**
    * Lifted from TSSLTransportFactory in Thrift-0.9.1. The method to create a client socket with an
-   * SSLContextFactory object is not visibile to us. Have to use SslConnectionParams instead of
+   * SSLContextFactory object is not visible to us. Have to use SslConnectionParams instead of
    * TSSLTransportParameters because no getters exist on TSSLTransportParameters.
    *
    * @param params
diff --git a/core/src/main/java/org/apache/accumulo/core/security/ColumnVisibility.java b/core/src/main/java/org/apache/accumulo/core/security/ColumnVisibility.java
index e73d8ee4e4..19026d8cac 100644
--- a/core/src/main/java/org/apache/accumulo/core/security/ColumnVisibility.java
+++ b/core/src/main/java/org/apache/accumulo/core/security/ColumnVisibility.java
@@ -207,7 +207,7 @@ public int compare(Node a, Node b) {
   }
 
   /*
-   * Convience method that delegates to normalize with a new NodeComparator constructed using the
+   * Convenience method that delegates to normalize with a new NodeComparator constructed using the
    * supplied expression.
    */
   public static Node normalize(Node root, byte[] expression) {
diff --git a/core/src/main/java/org/apache/accumulo/core/summary/Gatherer.java b/core/src/main/java/org/apache/accumulo/core/summary/Gatherer.java
index 07604bf52f..84be0d63e6 100644
--- a/core/src/main/java/org/apache/accumulo/core/summary/Gatherer.java
+++ b/core/src/main/java/org/apache/accumulo/core/summary/Gatherer.java
@@ -491,7 +491,7 @@ public SummaryCollection get(long timeout, TimeUnit unit)
 
   /**
    * This methods reads a subset of file paths into memory and groups them by location. Then it
-   * request sumaries for files from each location/tablet server.
+   * request summaries for files from each location/tablet server.
    */
   public Future<SummaryCollection> processPartition(ExecutorService execSrv, int modulus,
       int remainder) {
diff --git a/core/src/main/java/org/apache/accumulo/core/util/Merge.java b/core/src/main/java/org/apache/accumulo/core/util/Merge.java
index 81bd29b617..28f48d5382 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/Merge.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/Merge.java
@@ -217,7 +217,7 @@ protected void merge(Connector conn, String table, List<Size> sizes, int numToMe
 
   protected Iterator<Size> getSizeIterator(Connector conn, String tablename, Text start, Text end)
       throws MergeException {
-    // open up metatadata, walk through the tablets.
+    // open up metadata, walk through the tablets.
     Table.ID tableId;
     Scanner scanner;
     try {
diff --git a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/GuavaRateLimiter.java b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/GuavaRateLimiter.java
index 11bc5c0f9b..67e0ce5164 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/GuavaRateLimiter.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/GuavaRateLimiter.java
@@ -25,7 +25,7 @@
    * Constructor
    *
    * @param initialRate
-   *          Count of permits which should be made available per second. A nonpositive rate is
+   *          Count of permits which should be made available per second. A non-positive rate is
    *          taken to indicate there should be no limitation on rate.
    */
   public GuavaRateLimiter(long initialRate) {
@@ -43,7 +43,7 @@ public long getRate() {
    * Change the rate at which permits are made available.
    *
    * @param newRate
-   *          Count of permits which should be made available per second. A nonpositive rate is
+   *          Count of permits which should be made available per second. A non-positive rate is
    *          taken to indicate that there should be no limitation on rate.
    */
   public void setRate(long newRate) {
diff --git a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/RateLimiter.java b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/RateLimiter.java
index ab4db84068..2550ac8803 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/RateLimiter.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/RateLimiter.java
@@ -18,7 +18,7 @@
 
 public interface RateLimiter {
   /**
-   * Get current QPS of the rate limiter, with a nonpositive rate indicating no limit.
+   * Get current QPS of the rate limiter, with a non-positive rate indicating no limit.
    */
   long getRate();
 
diff --git a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/SharedRateLimiterFactory.java b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/SharedRateLimiterFactory.java
index bf94743925..4fe8ee97fe 100644
--- a/core/src/main/java/org/apache/accumulo/core/util/ratelimit/SharedRateLimiterFactory.java
+++ b/core/src/main/java/org/apache/accumulo/core/util/ratelimit/SharedRateLimiterFactory.java
@@ -72,8 +72,8 @@ public void run() {
     /**
      * Calculate the current rate for the {@link RateLimiter}.
      *
-     * @return Count of permits which should be provided per second. A nonpositive count is taken to
-     *         indicate that no rate limiting should be performed.
+     * @return Count of permits which should be provided per second. A non-positive count is taken
+     *         to indicate that no rate limiting should be performed.
      */
     long getDesiredRate();
   }
diff --git a/core/src/main/java/org/apache/accumulo/fate/AdminUtil.java b/core/src/main/java/org/apache/accumulo/fate/AdminUtil.java
index 1ea9a881ae..8bafac49b5 100644
--- a/core/src/main/java/org/apache/accumulo/fate/AdminUtil.java
+++ b/core/src/main/java/org/apache/accumulo/fate/AdminUtil.java
@@ -172,7 +172,7 @@ private FateStatus(List<TransactionStatus> transactions,
     }
 
     /**
-     * Get locks that are waiting to be aquired by non existent FATE transactions. These are table
+     * Get locks that are waiting to be acquired by non existent FATE transactions. These are table
      * or namespace locks.
      *
      * @return map where keys are transaction ids and values are a list of table IDs and/or
diff --git a/core/src/main/java/org/apache/accumulo/fate/ReadOnlyTStore.java b/core/src/main/java/org/apache/accumulo/fate/ReadOnlyTStore.java
index 2936447246..6d6b3a7613 100644
--- a/core/src/main/java/org/apache/accumulo/fate/ReadOnlyTStore.java
+++ b/core/src/main/java/org/apache/accumulo/fate/ReadOnlyTStore.java
@@ -108,7 +108,7 @@
   TStatus getStatus(long tid);
 
   /**
-   * Wait for the satus of a transaction to change
+   * Wait for the status of a transaction to change
    *
    * @param tid
    *          transaction id, need not have been reserved.
diff --git a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooCacheFactory.java b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooCacheFactory.java
index 58f1cfe7ab..f71346a5e7 100644
--- a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooCacheFactory.java
+++ b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooCacheFactory.java
@@ -33,7 +33,7 @@
    * arguments.
    *
    * @param zooKeepers
-   *          comma-seprated list of ZooKeeper host[:port]s
+   *          comma-separated list of ZooKeeper host[:port]s
    * @param sessionTimeout
    *          session timeout
    * @return cache object
@@ -55,7 +55,7 @@ public ZooCache getZooCache(String zooKeepers, int sessionTimeout) {
    * be returned for multiple calls with the same remaining arguments.
    *
    * @param zooKeepers
-   *          comma-seprated list of ZooKeeper host[:port]s
+   *          comma-separated list of ZooKeeper host[:port]s
    * @param sessionTimeout
    *          session timeout
    * @param watcher
diff --git a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooLock.java b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooLock.java
index e6bb8b149b..172ddb075f 100644
--- a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooLock.java
+++ b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooLock.java
@@ -361,7 +361,7 @@ public synchronized LockID getLockID() {
    * indicates if the lock was acquired in the past.... helps discriminate between the case where
    * the lock was never held, or held and lost....
    *
-   * @return true if the lock was aquired, otherwise false.
+   * @return true if the lock was acquired, otherwise false.
    */
   public synchronized boolean wasLockAcquired() {
     return lockWasAcquired;
diff --git a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooSession.java b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooSession.java
index 7a5079410d..584a7fc2ef 100644
--- a/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooSession.java
+++ b/core/src/main/java/org/apache/accumulo/fate/zookeeper/ZooSession.java
@@ -107,7 +107,7 @@ public static ZooKeeper connect(String host, int timeout, String scheme, byte[]
       } catch (IOException e) {
         if (e instanceof UnknownHostException) {
           /*
-           * Make sure we wait atleast as long as the JVM TTL for negative DNS responses
+           * Make sure we wait at least as long as the JVM TTL for negative DNS responses
            */
           sleepTime = Math.max(sleepTime,
               (AddressUtil.getAddressCacheNegativeTtl((UnknownHostException) e) + 1) * 1000);
diff --git a/core/src/test/java/org/apache/accumulo/core/client/ClientConfigurationTest.java b/core/src/test/java/org/apache/accumulo/core/client/ClientConfigurationTest.java
index 8212a2f8fa..df11c9d2b4 100644
--- a/core/src/test/java/org/apache/accumulo/core/client/ClientConfigurationTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/client/ClientConfigurationTest.java
@@ -83,7 +83,7 @@ public void testConfPath() throws IOException {
     assertEquals(clientConf.toString(),
         ClientConfiguration.getClientConfPath(clientConf.toString()));
 
-    // Something that doesn't exist should return itself (specifially, it shouldn't error)
+    // Something that doesn't exist should return itself (specifically, it shouldn't error)
     final File missing = new File("foobarbaz12332112");
     assertEquals(missing.toString(), ClientConfiguration.getClientConfPath(missing.toString()));
 
diff --git a/core/src/test/java/org/apache/accumulo/core/client/impl/TabletLocatorImplTest.java b/core/src/test/java/org/apache/accumulo/core/client/impl/TabletLocatorImplTest.java
index d73a4c0c9f..f47361f0ec 100644
--- a/core/src/test/java/org/apache/accumulo/core/client/impl/TabletLocatorImplTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/client/impl/TabletLocatorImplTest.java
@@ -876,7 +876,7 @@ public void testBinRanges3() throws Exception {
 
     runTest(tableName, ranges, metaCache, expected);
 
-    // test where start of range is not inclusive and same as tablet endrow
+    // test where start of range is not inclusive and same as tablet endRow
     ranges = nrl(nr("g", false, "m", true));
     expected = createExpectedBinnings("l2",
         nol(nke("foo", "m", "g"), nrl(nr("g", false, "m", true)))
@@ -885,7 +885,7 @@ public void testBinRanges3() throws Exception {
 
     runTest(tableName, ranges, metaCache, expected);
 
-    // test where start of range is inclusive and same as tablet endrow
+    // test where start of range is inclusive and same as tablet endRow
     ranges = nrl(nr("g", true, "m", true));
     expected = createExpectedBinnings("l1",
         nol(nke("foo", "g", null), nrl(nr("g", true, "m", true))), "l2",
diff --git a/core/src/test/java/org/apache/accumulo/core/client/impl/ThriftScannerTest.java b/core/src/test/java/org/apache/accumulo/core/client/impl/ThriftScannerTest.java
index 31c4e3271b..a5e4505239 100644
--- a/core/src/test/java/org/apache/accumulo/core/client/impl/ThriftScannerTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/client/impl/ThriftScannerTest.java
@@ -21,7 +21,7 @@
 import org.junit.Test;
 
 /**
- * Test calss for {@link ThriftScanner}.
+ * Test calls for {@link ThriftScanner}.
  */
 public class ThriftScannerTest {
 
diff --git a/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java b/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
index 6bfd6583eb..292a071c2b 100644
--- a/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/client/rfile/RFileTest.java
@@ -606,7 +606,7 @@ public void testSummaries() throws Exception {
         .selectSummaries(sc -> sc.equals(sc1)).read();
     checkSummaries(summaries, ImmutableMap.of("A&B", 800L, "A&B&C", 800L), 0);
 
-    // the following test check boundry conditions for start row and end row
+    // the following test check boundary conditions for start row and end row
     summaries = RFile.summaries().from(testFile, testFile2).withFileSystem(localFs)
         .selectSummaries(sc -> sc.equals(sc1)).startRow(rowStr(99)).read();
     checkSummaries(summaries, ImmutableMap.of("A&B", 400L, "A&B&C", 400L), 0);
diff --git a/core/src/test/java/org/apache/accumulo/core/conf/AccumuloConfigurationTest.java b/core/src/test/java/org/apache/accumulo/core/conf/AccumuloConfigurationTest.java
index 0fcfebdbcf..8bf3335a1a 100644
--- a/core/src/test/java/org/apache/accumulo/core/conf/AccumuloConfigurationTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/conf/AccumuloConfigurationTest.java
@@ -322,7 +322,7 @@ public void testScanExecutors() {
         .findFirst().get();
     Assert.assertEquals(6, sec2.maxThreads);
 
-    // ensure new prop overrides deperecated prop
+    // ensure new prop overrides deprecated prop
     tc.set(Property.TSERV_SCAN_EXECUTORS_DEFAULT_THREADS.getKey(), "9");
     Assert.assertEquals(9, sec.getCurrentMaxThreads());
     Assert.assertEquals(
diff --git a/core/src/test/java/org/apache/accumulo/core/file/rfile/RFileTest.java b/core/src/test/java/org/apache/accumulo/core/file/rfile/RFileTest.java
index 507090e44b..faf991051a 100644
--- a/core/src/test/java/org/apache/accumulo/core/file/rfile/RFileTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/file/rfile/RFileTest.java
@@ -2340,7 +2340,7 @@ public void testRootTabletEncryption() throws Exception {
         TabletsSection.ServerColumnFamily.TIME_COLUMN.getColumnQualifier(), 0);
     mfw.append(tableTimeKey, new Value((/* TabletTime.LOGICAL_TIME_ID */'L' + "0").getBytes()));
 
-    // table tablet's prevrow
+    // table tablet's prevRow
     Key tablePrevRowKey = new Key(tableExtent,
         TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.getColumnFamily(),
         TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.getColumnQualifier(), 0);
@@ -2361,7 +2361,7 @@ public void testRootTabletEncryption() throws Exception {
         TabletsSection.ServerColumnFamily.TIME_COLUMN.getColumnQualifier(), 0);
     mfw.append(defaultTimeKey, new Value((/* TabletTime.LOGICAL_TIME_ID */'L' + "0").getBytes()));
 
-    // default's prevrow
+    // default's prevRow
     Key defaultPrevRowKey = new Key(defaultExtent,
         TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.getColumnFamily(),
         TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.getColumnQualifier(), 0);
diff --git a/core/src/test/java/org/apache/accumulo/core/file/rfile/bcfile/CompressionTest.java b/core/src/test/java/org/apache/accumulo/core/file/rfile/bcfile/CompressionTest.java
index 496f8036b8..cc2de0dcd7 100644
--- a/core/src/test/java/org/apache/accumulo/core/file/rfile/bcfile/CompressionTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/file/rfile/bcfile/CompressionTest.java
@@ -81,7 +81,7 @@ public void testSingle() throws IOException {
     for (final Algorithm al : Algorithm.values()) {
       if (isSupported.get(al) != null && isSupported.get(al)) {
 
-        // first call to issupported should be true
+        // first call to isSupported should be true
         Assert.assertTrue(al + " is not supported, but should be", al.isSupported());
 
         Assert.assertNotNull(al + " should have a non-null codec", al.getCodec());
@@ -116,7 +116,7 @@ public void testManyStartNotNull() throws IOException, InterruptedException, Exe
     for (final Algorithm al : Algorithm.values()) {
       if (isSupported.get(al) != null && isSupported.get(al)) {
 
-        // first call to issupported should be true
+        // first call to isSupported should be true
         Assert.assertTrue(al + " is not supported, but should be", al.isSupported());
 
         final CompressionCodec codec = al.getCodec();
@@ -159,7 +159,7 @@ public void testManyDontStartUntilThread()
     for (final Algorithm al : Algorithm.values()) {
       if (isSupported.get(al) != null && isSupported.get(al)) {
 
-        // first call to issupported should be true
+        // first call to isSupported should be true
         Assert.assertTrue(al + " is not supported, but should be", al.isSupported());
 
         ExecutorService service = Executors.newFixedThreadPool(10);
@@ -195,7 +195,7 @@ public void testThereCanBeOnlyOne() throws IOException, InterruptedException, Ex
     for (final Algorithm al : Algorithm.values()) {
       if (isSupported.get(al) != null && isSupported.get(al)) {
 
-        // first call to issupported should be true
+        // first call to isSupported should be true
         Assert.assertTrue(al + " is not supported, but should be", al.isSupported());
 
         ExecutorService service = Executors.newFixedThreadPool(20);
diff --git a/core/src/test/java/org/apache/accumulo/core/iterators/system/SourceSwitchingIteratorTest.java b/core/src/test/java/org/apache/accumulo/core/iterators/system/SourceSwitchingIteratorTest.java
index ef41aac8f6..9ca655a4b4 100644
--- a/core/src/test/java/org/apache/accumulo/core/iterators/system/SourceSwitchingIteratorTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/iterators/system/SourceSwitchingIteratorTest.java
@@ -221,7 +221,7 @@ public void test4() throws Exception {
   }
 
   public void test5() throws Exception {
-    // esnure switchNow() works w/ deepCopy()
+    // ensure switchNow() works w/ deepCopy()
     TreeMap<Key,Value> tm1 = new TreeMap<>();
     put(tm1, "r1", "cf1", "cq1", 5, "v1");
     put(tm1, "r1", "cf1", "cq2", 5, "v2");
diff --git a/core/src/test/java/org/apache/accumulo/core/iterators/user/TransformingIteratorTest.java b/core/src/test/java/org/apache/accumulo/core/iterators/user/TransformingIteratorTest.java
index 002894c07f..297cd661fa 100644
--- a/core/src/test/java/org/apache/accumulo/core/iterators/user/TransformingIteratorTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/iterators/user/TransformingIteratorTest.java
@@ -192,7 +192,7 @@ public void testCreatingIllegalVisbility() throws Exception {
     setUpTransformIterator(IllegalVisKeyTransformingIterator.class, false);
     checkExpected(new TreeMap<>());
 
-    // ensure illegal vis is supressed when evaluations is done
+    // ensure illegal vis is suppressed when evaluations is done
     setUpTransformIterator(IllegalVisKeyTransformingIterator.class);
     checkExpected(new TreeMap<>());
   }
@@ -339,8 +339,8 @@ public void testCompactionScanFetchingColumnFamilies() throws Exception {
 
   @Test
   public void testCompactionDoesntFilterVisibilities() throws Exception {
-    // In scan mode, this should return nothing since it produces visibilites
-    // the user can't see. In compaction mode, however, the visibilites
+    // In scan mode, this should return nothing since it produces visibilities
+    // the user can't see. In compaction mode, however, the visibilities
     // should still show up.
     setUpTransformIterator(BadVisCompactionKeyTransformingIterator.class);
 
diff --git a/core/src/test/java/org/apache/accumulo/core/security/VisibilityEvaluatorTest.java b/core/src/test/java/org/apache/accumulo/core/security/VisibilityEvaluatorTest.java
index 8f001a641b..526c66e09d 100644
--- a/core/src/test/java/org/apache/accumulo/core/security/VisibilityEvaluatorTest.java
+++ b/core/src/test/java/org/apache/accumulo/core/security/VisibilityEvaluatorTest.java
@@ -97,7 +97,7 @@ public void testQuotedExpressions() throws VisibilityParseException {
     VisibilityEvaluator ct = new VisibilityEvaluator(auths);
     runQuoteTest(ct);
 
-    // constuct VisibilityEvaluator using another constructor and run test again
+    // construct VisibilityEvaluator using another constructor and run test again
     ct = new VisibilityEvaluator((AuthorizationContainer) auths);
     runQuoteTest(ct);
   }
diff --git a/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/junit4/BaseJUnit4IteratorTest.java b/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/junit4/BaseJUnit4IteratorTest.java
index 7d90ac957f..fa01198a61 100644
--- a/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/junit4/BaseJUnit4IteratorTest.java
+++ b/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/junit4/BaseJUnit4IteratorTest.java
@@ -46,7 +46,7 @@
  * &#064;Parameters
  * public static Object[][] data() {
  *   IteratorTestInput input = createIteratorInput();
- *   IteratorTestOutput expectedOutput = createIteratorOuput();
+ *   IteratorTestOutput expectedOutput = createIteratorOutput();
  *   List&lt;IteratorTestCase&gt; testCases = createTestCases();
  *   return BaseJUnit4IteratorTest.createParameters(input, expectedOutput, testCases);
  * }
diff --git a/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/testcases/OutputVerifyingTestCase.java b/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/testcases/OutputVerifyingTestCase.java
index 84ba2be48b..53bcdbf715 100644
--- a/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/testcases/OutputVerifyingTestCase.java
+++ b/iterator-test-harness/src/main/java/org/apache/accumulo/iteratortest/testcases/OutputVerifyingTestCase.java
@@ -19,8 +19,8 @@
 import org.apache.accumulo.iteratortest.IteratorTestOutput;
 
 /**
- * Base {@link IteratorTestCase} implementation that performs verifiation on the expected and actual
- * outcome.
+ * Base {@link IteratorTestCase} implementation that performs verification on the expected and
+ * actual outcome.
  */
 public abstract class OutputVerifyingTestCase implements IteratorTestCase {
 
diff --git a/minicluster/src/main/java/org/apache/accumulo/cluster/standalone/StandaloneClusterControl.java b/minicluster/src/main/java/org/apache/accumulo/cluster/standalone/StandaloneClusterControl.java
index 403a944cda..162c6a3468 100644
--- a/minicluster/src/main/java/org/apache/accumulo/cluster/standalone/StandaloneClusterControl.java
+++ b/minicluster/src/main/java/org/apache/accumulo/cluster/standalone/StandaloneClusterControl.java
@@ -45,7 +45,7 @@
 import com.google.common.collect.Maps;
 
 /**
- * Use the {@link RemoteShell} to control a standalone (possibly distibuted) Accumulo instance
+ * Use the {@link RemoteShell} to control a standalone (possibly distributed) Accumulo instance
  */
 public class StandaloneClusterControl implements ClusterControl {
   private static final Logger log = LoggerFactory.getLogger(StandaloneClusterControl.class);
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
index d2d234d0e7..2fb5560b88 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
@@ -49,7 +49,7 @@ private MiniAccumuloCluster(MiniAccumuloConfigImpl config) throws IOException {
   /**
    *
    * @param dir
-   *          An empty or nonexistant temp directoy that Accumulo and Zookeeper can store data in.
+   *          An empty or nonexistent temp directory that Accumulo and Zookeeper can store data in.
    *          Creating the directory is left to the user. Java 7, Guava, and Junit provide methods
    *          for creating temporary directories.
    * @param rootPassword
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
index 633468c024..ae6b98ff72 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
@@ -41,7 +41,7 @@ MiniAccumuloConfigImpl getImpl() {
 
   /**
    * @param dir
-   *          An empty or nonexistant directory that Accumulo and Zookeeper can store data in.
+   *          An empty or nonexistent directory that Accumulo and Zookeeper can store data in.
    *          Creating the directory is left to the user. Java 7, Guava, and Junit provide methods
    *          for creating temporary directories.
    * @param rootPassword
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloClusterImpl.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloClusterImpl.java
index 472603ff64..d1c0cd647a 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloClusterImpl.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloClusterImpl.java
@@ -373,7 +373,7 @@ public Process _exec(Class<?> clazz, ServerType serverType, Map<String,String> c
   /**
    *
    * @param dir
-   *          An empty or nonexistant temp directoy that Accumulo and Zookeeper can store data in.
+   *          An empty or nonexistent temp directory that Accumulo and Zookeeper can store data in.
    *          Creating the directory is left to the user. Java 7, Guava, and Junit provide methods
    *          for creating temporary directories.
    * @param rootPassword
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloConfigImpl.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloConfigImpl.java
index bad5a4e74a..bd2cddb36f 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloConfigImpl.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/impl/MiniAccumuloConfigImpl.java
@@ -94,7 +94,7 @@
 
   /**
    * @param dir
-   *          An empty or nonexistant directory that Accumulo and Zookeeper can store data in.
+   *          An empty or nonexistent directory that Accumulo and Zookeeper can store data in.
    *          Creating the directory is left to the user. Java 7, Guava, and Junit provide methods
    *          for creating temporary directories.
    * @param rootPassword
diff --git a/server/base/src/main/java/org/apache/accumulo/server/fs/ViewFSUtils.java b/server/base/src/main/java/org/apache/accumulo/server/fs/ViewFSUtils.java
index 31e698487c..1ceb1b5b69 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/fs/ViewFSUtils.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/fs/ViewFSUtils.java
@@ -54,7 +54,7 @@ public static Path matchingFileSystem(Path source, String[] options, Configurati
     Path match = null;
     int matchPrefixLen = 0;
 
-    // find the option with the longest commmon path prefix
+    // find the option with the longest common path prefix
     for (String option : options) {
       Path optionPath = new Path(option);
       if (isViewFS(optionPath, conf)) {
@@ -75,7 +75,7 @@ public static Path matchingFileSystem(Path source, String[] options, Configurati
           match = optionPath;
         } else if (match != null && commonPrefixLen == matchPrefixLen
             && optionPath.depth() < match.depth()) {
-          // take path with less depth when match perfix length is the same
+          // take path with less depth when match prefix length is the same
           match = optionPath;
         }
       }
diff --git a/server/base/src/main/java/org/apache/accumulo/server/fs/VolumeChooser.java b/server/base/src/main/java/org/apache/accumulo/server/fs/VolumeChooser.java
index 631c162a01..9010b0ccce 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/fs/VolumeChooser.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/fs/VolumeChooser.java
@@ -21,7 +21,7 @@
 
 /**
  * Helper used by {@link VolumeManager}s to select from a set of {@link Volume} URIs. N.B.
- * implemenations must be threadsafe. VolumeChooser.equals will be used for internal caching.
+ * implementations must be threadsafe. VolumeChooser.equals will be used for internal caching.
  *
  * <p>
  * Implementations may wish to store configuration in Accumulo's system configuration using the
diff --git a/server/base/src/main/java/org/apache/accumulo/server/master/balancer/GroupBalancer.java b/server/base/src/main/java/org/apache/accumulo/server/master/balancer/GroupBalancer.java
index 2eaeefb6aa..5e5a7a8e10 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/master/balancer/GroupBalancer.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/master/balancer/GroupBalancer.java
@@ -186,7 +186,7 @@ public long balance(SortedMap<TServerInstance,TabletServerStatus> current,
     // possibly have 2 tablets from a group. Below is an illustration of an ideal balancing of extra
     // tablets. To understand the illustration, the first column
     // shows tserver T1 with 2 tablets from G1, 1 tablet from G2, and two tablets from G3. EE means
-    // empty, put it there so eclipse formating would not mess up
+    // empty, put it there so eclipse formatting would not mess up
     // table.
     //
     // T1 | T2 | T3 | T4 | T5 | T6
diff --git a/server/base/src/main/java/org/apache/accumulo/server/rpc/TServerUtils.java b/server/base/src/main/java/org/apache/accumulo/server/rpc/TServerUtils.java
index 7e3f8aa89a..6a6de4e1a2 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/rpc/TServerUtils.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/rpc/TServerUtils.java
@@ -261,7 +261,7 @@ public void run() {
   }
 
   /**
-   * Creates a TTheadPoolServer for normal unsecure operation. Useful for comparing performance
+   * Creates a TThreadPoolServer for normal unsecure operation. Useful for comparing performance
    * against SSL or SASL transports.
    *
    * @param address
diff --git a/server/base/src/main/java/org/apache/accumulo/server/security/SecurityUtil.java b/server/base/src/main/java/org/apache/accumulo/server/security/SecurityUtil.java
index d923adad76..9935297bdb 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/security/SecurityUtil.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/security/SecurityUtil.java
@@ -43,7 +43,7 @@ public static void serverLogin(AccumuloConfiguration acuConf) {
 
   /**
    * Performs a Kerberos login using the given Kerberos principal and keytab if they are non-null
-   * and positive length Strings. This method automaticallys spawns a thread to renew the given
+   * and positive length Strings. This method automatically spawns a thread to renew the given
    * ticket upon successful login using {@link Property#GENERAL_KERBEROS_RENEWAL_PERIOD} as the
    * renewal period. This method does nothing if either {@code keyTab} or {@code principal} are null
    * or of zero length.
diff --git a/server/base/src/main/java/org/apache/accumulo/server/security/SystemCredentials.java b/server/base/src/main/java/org/apache/accumulo/server/security/SystemCredentials.java
index 8d8e01ed40..4580e62428 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/security/SystemCredentials.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/security/SystemCredentials.java
@@ -57,7 +57,7 @@ public static SystemCredentials get(String instanceID, SiteConfiguration siteCon
     if (siteConfig.getBoolean(Property.INSTANCE_RPC_SASL_ENABLED)) {
       // Use the server's kerberos principal as the Accumulo principal. We could also unwrap the
       // principal server-side, but the principal for SystemCredentials
-      // isnt' actually used anywhere, so it really doesn't matter. We can't include the kerberos
+      // isn't actually used anywhere, so it really doesn't matter. We can't include the kerberos
       // principal in the SystemToken as it would break equality when
       // different Accumulo servers are using different kerberos principals are their accumulo
       // principal
diff --git a/server/base/src/main/java/org/apache/accumulo/server/security/delegation/AuthenticationTokenKeyManager.java b/server/base/src/main/java/org/apache/accumulo/server/security/delegation/AuthenticationTokenKeyManager.java
index b31cf169c6..5cef9e1973 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/security/delegation/AuthenticationTokenKeyManager.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/security/delegation/AuthenticationTokenKeyManager.java
@@ -113,7 +113,7 @@ void updateStateFromCurrentKeys() {
 
         // Try to use the last key instead of creating a new one right away. This will present more
         // expected
-        // functionality if the active master happens to die for some reasonn
+        // functionality if the active master happens to die for some reason
         AuthenticationKey currentKey = secretManager.getCurrentKey();
         if (null != currentKey) {
           log.info("Updating last key update to {} from current secret manager key",
diff --git a/server/base/src/main/java/org/apache/accumulo/server/util/FileUtil.java b/server/base/src/main/java/org/apache/accumulo/server/util/FileUtil.java
index bf704f40b3..8e4d845a7a 100644
--- a/server/base/src/main/java/org/apache/accumulo/server/util/FileUtil.java
+++ b/server/base/src/main/java/org/apache/accumulo/server/util/FileUtil.java
@@ -239,7 +239,7 @@ public static double estimatePercentageLTE(VolumeManager fs, String tabletDir,
       List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(readers);
       MultiIterator mmfi = new MultiIterator(iters, true);
 
-      // skip the prevendrow
+      // skip the prevEndRow
       while (mmfi.hasTop() && mmfi.getTopKey().compareRow(prevEndRow) <= 0) {
         mmfi.next();
       }
@@ -333,7 +333,7 @@ public static double estimatePercentageLTE(VolumeManager fs, String tabletDir,
       List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(readers);
       MultiIterator mmfi = new MultiIterator(iters, true);
 
-      // skip the prevendrow
+      // skip the prevEndRow
       while (mmfi.hasTop() && mmfi.getTopKey().compareRow(prevEndRow) <= 0)
         mmfi.next();
 
diff --git a/server/master/src/main/java/org/apache/accumulo/master/tableOps/ClonePermissions.java b/server/master/src/main/java/org/apache/accumulo/master/tableOps/ClonePermissions.java
index 1d0b8ffbf2..eb7de8dbf5 100644
--- a/server/master/src/main/java/org/apache/accumulo/master/tableOps/ClonePermissions.java
+++ b/server/master/src/main/java/org/apache/accumulo/master/tableOps/ClonePermissions.java
@@ -57,7 +57,7 @@ public long isReady(long tid, Master environment) throws Exception {
     }
 
     // setup permissions in zookeeper before table info in zookeeper
-    // this way concurrent users will not get a spurious pemission denied
+    // this way concurrent users will not get a spurious permission denied
     // error
     try {
       return new CloneZookeeper(cloneInfo, environment.getContext());
diff --git a/server/master/src/test/java/org/apache/accumulo/master/replication/SequentialWorkAssignerTest.java b/server/master/src/test/java/org/apache/accumulo/master/replication/SequentialWorkAssignerTest.java
index 1131e6e84f..2b580ed2ae 100644
--- a/server/master/src/test/java/org/apache/accumulo/master/replication/SequentialWorkAssignerTest.java
+++ b/server/master/src/test/java/org/apache/accumulo/master/replication/SequentialWorkAssignerTest.java
@@ -57,7 +57,7 @@ public void basicZooKeeperCleanup() throws Exception {
     Map<String,Map<Table.ID,String>> queuedWork = new TreeMap<>();
     Map<Table.ID,String> cluster1Work = new TreeMap<>();
 
-    // Two files for cluster1, one for table '1' and another for table '2' we havce assigned work
+    // Two files for cluster1, one for table '1' and another for table '2' we haven't assigned work
     // for
     cluster1Work.put(Table.ID.of("1"), DistributedWorkQueueWorkAssignerHelper.getQueueKey("file1",
         new ReplicationTarget("cluster1", "1", Table.ID.of("1"))));
diff --git a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/gc/GarbageCollectorStatus.java b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/gc/GarbageCollectorStatus.java
index 97a063f992..df16848e73 100644
--- a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/gc/GarbageCollectorStatus.java
+++ b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/gc/GarbageCollectorStatus.java
@@ -37,7 +37,7 @@ public GarbageCollectorStatus() {}
    * Groups gc status into files and wals
    *
    * @param status
-   *          garbace collector status
+   *          garbage collector status
    */
   public GarbageCollectorStatus(GCStatus status) {
     if (null != status) {
diff --git a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/tables/CompactionsList.java b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/tables/CompactionsList.java
index 3602d685a9..e9c523eebf 100644
--- a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/tables/CompactionsList.java
+++ b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/tables/CompactionsList.java
@@ -30,7 +30,7 @@
   public CompactionsList() {}
 
   /**
-   * Generate a compation list
+   * Generate a compaction list
    *
    * @param running
    *          Number of running compactions
diff --git a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/trace/AddlInformation.java b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/trace/AddlInformation.java
index fa65608622..1a862d5e64 100644
--- a/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/trace/AddlInformation.java
+++ b/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/trace/AddlInformation.java
@@ -20,7 +20,7 @@
 import java.util.List;
 
 /**
- * Generates addiotional information for the selected trace
+ * Generates additional information for the selected trace
  *
  * @since 2.0.0
  */
diff --git a/server/tracer/src/main/java/org/apache/accumulo/tracer/TraceServer.java b/server/tracer/src/main/java/org/apache/accumulo/tracer/TraceServer.java
index b277135e63..228532ab2d 100644
--- a/server/tracer/src/main/java/org/apache/accumulo/tracer/TraceServer.java
+++ b/server/tracer/src/main/java/org/apache/accumulo/tracer/TraceServer.java
@@ -174,8 +174,8 @@ public void span(RemoteSpan s) throws TException {
           log.debug("discarded span due to rejection of mutation: " + spanMutation, exception);
         }
         /*
-         * XXX this could be e.g. an IllegalArgumentExceptoion if we're trying to write this
-         * mutation to a writer that has been closed since we retrieved it
+         * XXX this could be e.g. an IllegalArgumentException if we're trying to write this mutation
+         * to a writer that has been closed since we retrieved it
          */
       } catch (RuntimeException exception) {
         log.warn("Unable to write mutation to table; discarding span. set log"
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/FileManager.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/FileManager.java
index 313067e872..e0d3ab9f2d 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/FileManager.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/FileManager.java
@@ -561,7 +561,7 @@ public void setInterruptFlag(AtomicBoolean flag) {
         }
 
         if (sawTimeSet) {
-          // constucting FileRef is expensive so avoid if not needed
+          // constructing FileRef is expensive so avoid if not needed
           DataFileValue value = files.get(new FileRef(filename));
           if (value.isTimeSet()) {
             iter = new TimeSettingIterator(iter, value.getTime());
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/TabletServer.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/TabletServer.java
index e0a36056a2..2ce12d79a5 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/TabletServer.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/TabletServer.java
@@ -998,7 +998,7 @@ public void applyUpdates(TInfo tinfo, long updateID, TKeyExtent tkeyExtent,
             try {
               flush(us);
             } catch (HoldTimeoutException hte) {
-              // Assumption is that the client has timed out and is gone. If thats not the case,
+              // Assumption is that the client has timed out and is gone. If that's not the case,
               // then removing the session should cause the client to fail
               // in such a way that it retries.
               log.debug("HoldTimeoutException during applyUpdates, removing session");
@@ -1186,7 +1186,7 @@ public UpdateErrors closeUpdate(TInfo tinfo, long updateID) throws NoSuchScanIDE
       try {
         flush(us);
       } catch (HoldTimeoutException e) {
-        // Assumption is that the client has timed out and is gone. If thats not the case throw an
+        // Assumption is that the client has timed out and is gone. If that's not the case throw an
         // exception that will cause it to retry.
         log.debug("HoldTimeoutException during closeUpdate, reporting no such session");
         throw new NoSuchScanIDException();
@@ -1251,7 +1251,7 @@ public void update(TInfo tinfo, TCredentials credentials, TKeyExtent tkeyExtent,
         try {
           TabletServer.this.resourceManager.waitUntilCommitsAreEnabled();
         } catch (HoldTimeoutException hte) {
-          // Major hack. Assumption is that the client has timed out and is gone. If thats not the
+          // Major hack. Assumption is that the client has timed out and is gone. If that's not the
           // case, then throwing the following will let client know there
           // was a failure and it should retry.
           throw new NotServingTabletException(tkeyExtent);
@@ -1535,8 +1535,8 @@ public TConditionalSession startConditionalUpdate(TInfo tinfo, TCredentials cred
         try {
           TabletServer.this.resourceManager.waitUntilCommitsAreEnabled();
         } catch (HoldTimeoutException hte) {
-          // Assumption is that the client has timed out and is gone. If thats not the case throw an
-          // exception that will cause it to retry.
+          // Assumption is that the client has timed out and is gone. If that's not the case throw
+          // an exception that will cause it to retry.
           log.debug("HoldTimeoutException during conditionalUpdate, reporting no such session");
           throw new NoSuchScanIDException();
         }
@@ -1600,7 +1600,7 @@ public void splitTablet(TInfo tinfo, TCredentials credentials, TKeyExtent tkeyEx
       try {
         namespaceId = Tables.getNamespaceId(context, tableId);
       } catch (TableNotFoundException ex) {
-        // tableOperationsImpl catches ThriftSeccurityException and checks for missing table
+        // tableOperationsImpl catches ThriftSecurityException and checks for missing table
         throw new ThriftSecurityException(credentials.getPrincipal(),
             SecurityErrorCode.TABLE_DOESNT_EXIST);
       }
@@ -3598,7 +3598,7 @@ public final RateLimiter getMajorCompactionReadLimiter() {
   }
 
   /**
-   * Get the RateLimiter for writes during major compations on this tserver. All reads performed
+   * Get the RateLimiter for writes during major compactions on this tserver. All reads performed
    * during major compactions are throttled to conform to this RateLimiter.
    */
   public final RateLimiter getMajorCompactionWriteLimiter() {
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/compaction/strategies/TooManyDeletesCompactionStrategy.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/compaction/strategies/TooManyDeletesCompactionStrategy.java
index 7337c88530..8e88a117ce 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/compaction/strategies/TooManyDeletesCompactionStrategy.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/compaction/strategies/TooManyDeletesCompactionStrategy.java
@@ -54,7 +54,7 @@
  * <p>
  * If the delete summarizer was configured on a table that already had files, then those files will
  * have not summary information. This strategy can still proceed in this situation. It will fall
- * back to using Accumulo's estimated entires per file in this case. For the files without summary
+ * back to using Accumulo's estimated entries per file in this case. For the files without summary
  * information the estimated number of deletes will be zero. This fall back method will
  * underestimate deletes which will not lead to false positives, except for the case of bulk
  * imported files. Accumulo estimates that bulk imported files have zero entires. The second option
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/log/TabletServerLogger.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/log/TabletServerLogger.java
index 01bed7c7e9..ca726aefcb 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/log/TabletServerLogger.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/log/TabletServerLogger.java
@@ -127,7 +127,7 @@ private static void testLockAndRun(final ReadWriteLock rwlock, TestCallWithWrite
     try {
       // does some condition exist that needs the write lock?
       if (code.test()) {
-        // Yes, let go of the readlock
+        // Yes, let go of the readLock
         rwlock.readLock().unlock();
         // Grab the write lock
         rwlock.writeLock().lock();
@@ -138,7 +138,7 @@ private static void testLockAndRun(final ReadWriteLock rwlock, TestCallWithWrite
             code.withWriteLock();
           }
         } finally {
-          // regain the readlock
+          // regain the readLock
           rwlock.readLock().lock();
           // unlock the write lock
           rwlock.writeLock().unlock();
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/DatafileManager.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/DatafileManager.java
index e2026a2487..55a364b5de 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/DatafileManager.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/DatafileManager.java
@@ -389,7 +389,7 @@ void bringMinorCompactionOnline(FileRef tmpDatafile, FileRef newDatafile, FileRe
     // for scans to finish like major compactions do.... used to wait for scans to finish
     // here, but that was incorrect because a scan could start after waiting but before
     // memory was updated... assuming the file is always in use by scans leads to
-    // one uneeded metadata update when it was not actually in use
+    // one unneeded metadata update when it was not actually in use
     Set<FileRef> filesInUseByScans = Collections.emptySet();
     if (absMergeFile != null)
       filesInUseByScans = Collections.singleton(absMergeFile);
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Scanner.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Scanner.java
index 48546f8f94..e24c3316bd 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Scanner.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Scanner.java
@@ -43,7 +43,7 @@
   /**
    * A fair semaphore of one is used since explicitly know the access pattern will be one thread to
    * read and another to call close if the session becomes idle. Since we're explicitly preventing
-   * re-entrance, we're currently using a Sempahore. If at any point we decide read needs to be
+   * re-entrance, we're currently using a Semaphore. If at any point we decide read needs to be
    * re-entrant, we can switch to a Reentrant lock.
    */
   private Semaphore scannerSemaphore;
diff --git a/shell/src/main/java/org/apache/accumulo/shell/Shell.java b/shell/src/main/java/org/apache/accumulo/shell/Shell.java
index 9db3a02b63..bdab449b75 100644
--- a/shell/src/main/java/org/apache/accumulo/shell/Shell.java
+++ b/shell/src/main/java/org/apache/accumulo/shell/Shell.java
@@ -901,7 +901,7 @@ public abstract int execute(String fullCommand, CommandLine cl, Shell shellState
 
     // OPTIONAL methods to override:
 
-    // the general version of getname uses reflection to get the class name
+    // the general version of getName uses reflection to get the class name
     // and then cuts off the suffix -Command to get the name of the command
     public String getName() {
       String s = this.getClass().getName();
diff --git a/test/src/main/java/org/apache/accumulo/harness/AccumuloITBase.java b/test/src/main/java/org/apache/accumulo/harness/AccumuloITBase.java
index 177b475e27..3cbf3c26b3 100644
--- a/test/src/main/java/org/apache/accumulo/harness/AccumuloITBase.java
+++ b/test/src/main/java/org/apache/accumulo/harness/AccumuloITBase.java
@@ -76,7 +76,7 @@ public static File createTestDir(String name) {
    * failed.
    *
    * Note that this provides a upper bound on test times, even in the presence of Test annotations
-   * with a timeout. That is, the Test annotatation can make the timing tighter but will not be able
+   * with a timeout. That is, the Test annotation can make the timing tighter but will not be able
    * to allow a timeout that takes longer.
    *
    * Defaults to no timeout and can be changed via two mechanisms
diff --git a/test/src/main/java/org/apache/accumulo/test/BalanceFasterIT.java b/test/src/main/java/org/apache/accumulo/test/BalanceFasterIT.java
index 6a11f90917..66418ede8b 100644
--- a/test/src/main/java/org/apache/accumulo/test/BalanceFasterIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/BalanceFasterIT.java
@@ -74,7 +74,7 @@ public void test() throws Exception {
     conn.tableOperations().addSplits(tableName, splits);
     // give a short wait for balancing
     sleepUninterruptibly(10, TimeUnit.SECONDS);
-    // find out where the tabets are
+    // find out where the tablets are
     Iterator<Integer> i;
     try (Scanner s = conn.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
       s.fetchColumnFamily(MetadataSchema.TabletsSection.CurrentLocationColumnFamily.NAME);
diff --git a/test/src/main/java/org/apache/accumulo/test/ExistingMacIT.java b/test/src/main/java/org/apache/accumulo/test/ExistingMacIT.java
index 947b67f5c1..dc1f5ca97f 100644
--- a/test/src/main/java/org/apache/accumulo/test/ExistingMacIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/ExistingMacIT.java
@@ -100,7 +100,7 @@ public void testExistingInstance() throws Exception {
     bw.close();
 
     conn.tableOperations().flush("table1", null, null, true);
-    // TOOD use constants
+    // TODO use constants
     conn.tableOperations().flush(MetadataTable.NAME, null, null, true);
     conn.tableOperations().flush(RootTable.NAME, null, null, true);
 
diff --git a/test/src/main/java/org/apache/accumulo/test/LargeSplitRowIT.java b/test/src/main/java/org/apache/accumulo/test/LargeSplitRowIT.java
index 93fd797486..b9c9a685e4 100644
--- a/test/src/main/java/org/apache/accumulo/test/LargeSplitRowIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/LargeSplitRowIT.java
@@ -297,7 +297,7 @@ private void automaticSplit(int max, int spacing) throws Exception {
     Assert.assertEquals(10, extra);
     Assert.assertEquals(max, count);
 
-    // Make sure no splits occured in the table
+    // Make sure no splits occurred in the table
     Assert.assertEquals(0, conn.tableOperations().listSplits(tableName).size());
   }
 
diff --git a/test/src/main/java/org/apache/accumulo/test/MetaConstraintRetryIT.java b/test/src/main/java/org/apache/accumulo/test/MetaConstraintRetryIT.java
index 74ad75c0b9..65f51ce463 100644
--- a/test/src/main/java/org/apache/accumulo/test/MetaConstraintRetryIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/MetaConstraintRetryIT.java
@@ -48,7 +48,7 @@ public void test() throws Exception {
     KeyExtent extent = new KeyExtent(Table.ID.of("5"), null, null);
 
     Mutation m = new Mutation(extent.getMetadataEntry());
-    // unknown columns should cause contraint violation
+    // unknown columns should cause constraint violation
     m.put("badcolfam", "badcolqual", "3");
 
     try {
diff --git a/test/src/main/java/org/apache/accumulo/test/VolumeIT.java b/test/src/main/java/org/apache/accumulo/test/VolumeIT.java
index 0a85dc3869..0689c62265 100644
--- a/test/src/main/java/org/apache/accumulo/test/VolumeIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/VolumeIT.java
@@ -504,7 +504,7 @@ public void testRemoveVolumes() throws Exception {
     conf.writeXml(fos);
     fos.close();
 
-    // start cluster and verify that volume was decommisioned
+    // start cluster and verify that volume was decommissioned
     cluster.start();
 
     Connector conn = cluster.getConnector("root", new PasswordToken(ROOT_PASSWORD));
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/ConstraintIT.java b/test/src/main/java/org/apache/accumulo/test/functional/ConstraintIT.java
index a142f855c0..508fe900e8 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/ConstraintIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/ConstraintIT.java
@@ -184,7 +184,7 @@ private void test1(String tableName) throws Exception {
             "Unexpected extra key or value " + entry.getKey() + " " + entry.getValue());
       }
 
-      // add a constraint that references a non-existant class
+      // add a constraint that references a non-existent class
       getConnector().tableOperations().setProperty(tableName,
           Property.TABLE_CONSTRAINT_PREFIX + "1", "com.foobar.nonExistantClass");
       sleepUninterruptibly(1, TimeUnit.SECONDS);
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/KerberosRenewalIT.java b/test/src/main/java/org/apache/accumulo/test/functional/KerberosRenewalIT.java
index 36a4d24490..e5882fb989 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/KerberosRenewalIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/KerberosRenewalIT.java
@@ -141,7 +141,7 @@ public void stopMac() throws Exception {
     }
   }
 
-  // Intentially setting the Test annotation timeout. We do not want to scale the timeout.
+  // Intentionally setting the Test annotation timeout. We do not want to scale the timeout.
   @Test(timeout = TEST_DURATION)
   public void testReadAndWriteThroughTicketLifetime() throws Exception {
     // Attempt to use Accumulo for a duration of time that exceeds the Kerberos ticket lifetime.
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/NativeMapIT.java b/test/src/main/java/org/apache/accumulo/test/functional/NativeMapIT.java
index 0cbbe02715..32e33ee150 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/NativeMapIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/NativeMapIT.java
@@ -120,7 +120,7 @@ private void insertAndVerify(NativeMap nm, int start, int end, int valueOffset)
       iter = nm.iterator(newKey(i));
       verifyIterator(i, end, valueOffset, iter);
 
-      // lookup nonexistant key that falls after existing key
+      // lookup nonexistent key that falls after existing key
       iter = nm.iterator(newKey(i, 1, 1, 1, 1, false));
       verifyIterator(i + 1, end, valueOffset, iter);
     }
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/ServerSideErrorIT.java b/test/src/main/java/org/apache/accumulo/test/functional/ServerSideErrorIT.java
index dadc5ac24f..c7ab130396 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/ServerSideErrorIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/ServerSideErrorIT.java
@@ -111,7 +111,7 @@ public void run() throws Exception {
         entry.getKey();
       }
 
-      // set a non existant iterator, should cause scan to fail on server side
+      // set a nonexistent iterator, should cause scan to fail on server side
       scanner.addScanIterator(new IteratorSetting(100, "bogus", "com.bogus.iterator"));
 
       caught = false;
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/SummaryIT.java b/test/src/main/java/org/apache/accumulo/test/functional/SummaryIT.java
index 41fedbff27..0b9a7aba99 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/SummaryIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/SummaryIT.java
@@ -336,7 +336,7 @@ public void selectionTest() throws Exception {
     checkSummary(summaries, sc1, TOTAL_STAT, 100_000L, MIN_TIMESTAMP_STAT, stats.getMin(),
         MAX_TIMESTAMP_STAT, stats.getMax(), DELETES_STAT, 0L);
 
-    // retrieve a non-existant summary
+    // retrieve a nonexistent summary
     SummarizerConfiguration sc3 = SummarizerConfiguration.builder(KeySizeSummarizer.class.getName())
         .addOption("maxLen", "256").build();
     summaries = c.tableOperations().summaries(table).withConfiguration(sc3).retrieve();
@@ -433,8 +433,8 @@ public boolean accept(Key k, Value v) {
   }
 
   /**
-   * A compaction strategy that intitiates a compaction when {@code foo} occurs more than
-   * {@code bar} in the data. The {@link FooCounter} summary data is used to make the determination.
+   * A compaction strategy that initiates a compaction when {@code foo} occurs more than {@code bar}
+   * in the data. The {@link FooCounter} summary data is used to make the determination.
    */
   public static class FooCS extends CompactionStrategy {
 
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/TableChangeStateIT.java b/test/src/main/java/org/apache/accumulo/test/functional/TableChangeStateIT.java
index 533cc2a621..635c2c7521 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/TableChangeStateIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/TableChangeStateIT.java
@@ -326,7 +326,7 @@ private void createData(final String tableName) {
   }
 
   /**
-   * Provides timing information for oline operation.
+   * Provides timing information for online operation.
    */
   private static class OnlineOpTiming {
 
diff --git a/test/src/main/java/org/apache/accumulo/test/functional/TooManyDeletesIT.java b/test/src/main/java/org/apache/accumulo/test/functional/TooManyDeletesIT.java
index 5c2902fa24..5c72f1e551 100644
--- a/test/src/main/java/org/apache/accumulo/test/functional/TooManyDeletesIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/functional/TooManyDeletesIT.java
@@ -44,7 +44,7 @@ public void tooManyDeletesCompactionStrategyIT() throws Exception {
 
     SummarizerConfiguration sc = SummarizerConfiguration.builder(DeletesSummarizer.class).build();
 
-    // TODO open issue about programatic config of compaction strategies
+    // TODO open issue about programmatic config of compaction strategies
 
     NewTableConfiguration ntc = new NewTableConfiguration().enableSummarization(sc);
     HashMap<String,String> props = new HashMap<>();
diff --git a/test/src/main/java/org/apache/accumulo/test/proxy/SimpleProxyBase.java b/test/src/main/java/org/apache/accumulo/test/proxy/SimpleProxyBase.java
index c1d708d3c1..add077198f 100644
--- a/test/src/main/java/org/apache/accumulo/test/proxy/SimpleProxyBase.java
+++ b/test/src/main/java/org/apache/accumulo/test/proxy/SimpleProxyBase.java
@@ -2299,7 +2299,7 @@ public void testConditionalWriter() throws Exception {
     assertScan(new String[][] {{"00345", "data", "img", "567890"}, {"00345", "meta", "seq", "2"},
         {"00346", "meta", "seq", "1"}}, tableName);
 
-    // test setting timestamp on condition to a non-existant version
+    // test setting timestamp on condition to a nonexistent version
     updates.clear();
 
     updates.put(s2bb("00345"),
@@ -2748,7 +2748,7 @@ public void namespaceOperations() throws Exception {
     assertEquals("System namespace is wrong", client.systemNamespace(), Namespace.ACCUMULO);
     assertEquals("Default namespace is wrong", client.defaultNamespace(), Namespace.DEFAULT);
 
-    // namespace existance and namespace listing
+    // namespace existence and namespace listing
     assertTrue("Namespace created during setup should exist",
         client.namespaceExists(creds, namespaceName));
     assertTrue("Namespace listing should contain namespace created during setup",
diff --git a/test/src/main/java/org/apache/accumulo/test/replication/MultiTserverReplicationIT.java b/test/src/main/java/org/apache/accumulo/test/replication/MultiTserverReplicationIT.java
index 64a13da56a..e2e6af0f57 100644
--- a/test/src/main/java/org/apache/accumulo/test/replication/MultiTserverReplicationIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/replication/MultiTserverReplicationIT.java
@@ -79,7 +79,7 @@ public void tserverReplicationServicePortsAreAdvertised() throws Exception {
         }
       }
 
-      // Each tserver should also have equial replicaiton services running internally
+      // Each tserver should also have equal replication services running internally
       Assert.assertEquals("Expected an equal number of replication servicers and tservers",
           tserverHost.size(), replicationServices.size());
     }
diff --git a/test/src/main/java/org/apache/accumulo/test/replication/UnorderedWorkAssignerReplicationIT.java b/test/src/main/java/org/apache/accumulo/test/replication/UnorderedWorkAssignerReplicationIT.java
index b58c11854a..aa1400e65a 100644
--- a/test/src/main/java/org/apache/accumulo/test/replication/UnorderedWorkAssignerReplicationIT.java
+++ b/test/src/main/java/org/apache/accumulo/test/replication/UnorderedWorkAssignerReplicationIT.java
@@ -398,7 +398,7 @@ public void dataReplicatedToCorrectTable() throws Exception {
       connMaster.tableOperations().setProperty(masterTable2,
           Property.TABLE_REPLICATION_TARGET.getKey() + peerClusterName, peerTableId2);
 
-      // Wait for zookeeper updates (configuration) to propogate
+      // Wait for zookeeper updates (configuration) to propagate
       sleepUninterruptibly(3, TimeUnit.SECONDS);
 
       // Write some data to table1


 

----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services
diff --git a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Tablet.java b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Tablet.java
index e783f3f10e..73abe2b7e4 100644
--- a/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Tablet.java
+++ b/server/tserver/src/main/java/org/apache/accumulo/tserver/tablet/Tablet.java
@@ -1024,7 +1024,7 @@ public void flush(long tableFlushID) {
   public boolean initiateMinorCompaction(MinorCompactionReason mincReason) {
     if (isClosed()) {
       // don't bother trying to get flush id if closed... could be closed after this check but that
-      // is ok... just trying to cut down on uneeded log messages....
+      // is ok... just trying to cut down on unneeded log messages....
       return false;
     }
 
@@ -1890,14 +1890,14 @@ private CompactionStats _majorCompact(MajorCompactionReason reason)
           return majCStats;
         }
       } else {
         // If no original files will exist at the end of the compaction, we do not have to propogate
         // deletes
         Set<FileRef> droppedFiles = new HashSet<>();
         droppedFiles.addAll(inputFiles);
         if (plan != null)
           droppedFiles.addAll(plan.deleteFiles);
         propogateDeletes = !(droppedFiles.equals(allFiles.keySet()));
-        log.debug("Major compaction plan: {} propogate deletes : {}", plan, propogateDeletes);
+        log.debug("Major compaction plan: {} propagate deletes : {}", plan, propogateDeletes);
         filesToCompact = new HashMap<>(allFiles);
         filesToCompact.keySet().retainAll(inputFiles);
 
@@ -2397,7 +2397,7 @@ public void importMapFiles(long tid, Map<FileRef,MapFileInfo> fileMap, boolean s
         throw new IOException("tablet " + extent + " is closed");
       }
 
-      // TODO check seems uneeded now - ACCUMULO-1291
+      // TODO check seems unneeded now - ACCUMULO-1291
       long lockWait = System.currentTimeMillis() - now;
       if (lockWait > getTabletServer().getConfiguration()
           .getTimeInMillis(Property.GENERAL_RPC_TIMEOUT)) {
@@ -2510,10 +2510,10 @@ public void removeInUseLogs(Set<DfsLogger> candidates) {
       }
 
       otherLogs = Collections.emptySet();
-      // Intentionally NOT calling rebuildReferenedLogs() here as that could cause GC of in use
-      // walogs(see #539). The clearing of otherLogs is reflected in refererncedLogs when
-      // finishClearingUnusedLogs() calls rebuildReferenedLogs(). See the comments in
-      // rebuildReferenedLogs() for more info.
+      // Intentionally NOT calling rebuildReferencedLogs() here as that could cause GC of in use
+      // walogs(see #539). The clearing of otherLogs is reflected in ReferencedLogs when
+      // finishClearingUnusedLogs() calls rebuildReferencedLogs(). See the comments in
+      // rebuildReferencedLogs() for more info.
 
       if (unusedLogs.size() > 0)
         removingLogs = true;
@@ -1890,14 +1890,14 @@ private CompactionStats _majorCompact(MajorCompactionReason reason)
         }
       } else {
-        // If no original files will exist at the end of the compaction, we do not have to propogate
+        // If no original files will exist at the end of the compaction, we do not have to propagate
         // deletes
         Set<FileRef> droppedFiles = new HashSet<>();